<?php

namespace Drupal\workgrid_toolbar_oauth\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Provides an Workgrid Toolbar OAuth block.
 *
 * @Block(
 *   id = "workgrid_toolbar_oauth",
 *   admin_label = @Translation("Workgrid Toolbar OAuth"),
 *   category = @Translation("Workgrid Toolbar Oauth")
 * )
 */
class WorkgridToolbarOauthBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'marginbottom' => $this->configuration['marginbottom'],
      'margintop' => $this->configuration['margintop'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {

    $form['margintop'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Margin Top'),
      '#description' => $this->t('Margin in pixels - example: 20'),
      '#default_value' => $this->configuration['margintop'],
    ];

    $form['marginbottom'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Margin Bottom'),
      '#description' => $this->t('Margin in pixels - example: 20'),
      '#default_value' => $this->configuration['marginbottom'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['margintop'] = $form_state->getValue('margintop');
    $this->configuration['marginbottom'] = $form_state->getValue('marginbottom');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $workgrid_toolbar_oauth_config = \Drupal::config('workgrid_toolbar_oauth.settings');
    $build['content'] = [
      '#attached' => [
        'drupalSettings' => [
          'workgrid_toolbar_oauth' => [
            'spaceId' => $workgrid_toolbar_oauth_config->get('spaceId'),
            'companyCode' => $workgrid_toolbar_oauth_config->get('companyCode'),
            'margintop' => $this->configuration['margintop'],
            'marginbottom' => $this->configuration['marginbottom'],
          ],
        ],
        'library' => [
          'workgrid_toolbar_oauth/workgrid_toolbar_oauth',
        ],
      ],
    ];
    return $build;
  }

  /**
   * Checks access for the users task page.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The account viewing the page.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIf($account->isAuthenticated());
  }

}
